==> bbwa-0.0.5.tar.gz: bbwa-0.0.5/right.php <==
<?php
//
// BBWA
// right.php
// Ʋɽ
// Teppei KAKU <teppei@sat.co.jp>
//

include("variables.php");
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">


<?php
print("<link rel=\"stylesheet\" type=\"text/css\" href=\"Themes/${theme}.css\">");
?>


<script language="JavaScript">
<!--
function openWindow(urlString) {
  var arg = "toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes";
  LARGEVIEW = window.open(urlString, "LRGEVIEW", arg);
  LARGEVIEW.focus();
}
//-->
</script>
<noscript>
<h4><blink>
顼: JavaScript ͭˤʤȤޤ!!
</blink></h4>
</noscript>
</head>
<body class="right">
<table border="0" width="100%" align="center">


<?php
include("functions.php");

// åɤ߹
if (isset($_COOKIE['NAME'])) {
  $nameValue = "value=\"" . htmlspecialchars($_COOKIE['NAME']) . "\"";
} else {
  $nameValue = "";
}
if (isset($_COOKIE['EMAIL'])) {
  $mailValue = "value=\"" . htmlspecialchars($_COOKIE['EMAIL']) . "\"";
} else {
  $mailValue = "";
}
if (isset($_COOKIE['PASS'])) {
  $passValue = "value=\"" . htmlspecialchars($_COOKIE['PASS']) . "\"";
} else {
  $passValue = "";
}
if (isset($_COOKIE['REPNAME'])) {
  $repValue = "value=\"" . htmlspecialchars($_COOKIE['REPNAME']) . "\"";
} else {
  $repValue = "";
}
?>


<tr><td class="right">
<table border="0" width="100%">


<?php
if (isset($_GET['img'])) {
  // ξܺپɽ
  $imgSize = getimagesize($dirName . $_GET['img']);
  $mesText = file("${dirName}Messages/${_GET['img']}_mes.txt");
  $mesElem = explode("|||", $mesText[0]);

  print("<tr><td valign=\"top\">");
  print("<table border=\"0\">");

  print("<tr><td nowrap align=\"right\" valign=\"top\">ȥ:</td><td>");
  print("<a href=\"JavaScript:openWindow('./largeview.php?img=${_GET['img']}')\">");
  $mesElem[2] = htmlspecialchars($mesElem[2]);
  print("<strong>${mesElem[2]}</strong></a></td></tr>");

  print("<tr><td nowrap align=\"right\" valign=\"top\">Ƽ:</td><td>");
  if ($mesElem[4] != "NOMAIL") {
    $mesElem[4] = htmlspecialchars($mesElem[4]);
    print("<a href=\"mailto:${mesElem[4]}\">");
  }
  $mesElem[3] = htmlspecialchars($mesElem[3]);
  print("<strong>${mesElem[3]}</strong>");
  if ($mesElem[4] != "NOMAIL") {
    print("</a>");
  }
  print("</td></tr>");

  print("<tr><td nowrap align=\"right\" valign=\"top\">:</td><td>");
  print("<strong>${mesElem[5]}</strong></td></tr>");

  $fSize = (int) ((filesize($dirName . $_GET['img']) / 1024) + 1);
  print("<tr><td nowrap align=\"right\" valign=\"top\">:</td>");
  print("<td>${imgSize[0]}x${imgSize[1]} ԥ, ${fSize} KB<br><br></td></tr>");

  print("<tr><td nowrap align=\"right\" valign=\"top\">:");
  if (!ereg("^NOCOM(\r\n|\r|\n)$", $mesElem[7])) {
    $mesElem[7] = messageParse($mesElem[7]);
    print("</td><td style=\"padding-right:10px;\">${mesElem[7]}");
  }

  echo <<<EOD
</td></tr></table>
</td><td valign="top" align="right">
<table border="0"><tr><td class="photoframe" align="center">
<a href="JavaScript:openWindow('./largeview.php?img=${_GET['img']}')">
EOD;

  if (eregi("\.gif$", $_GET['img'])) {
    print("<img src=\"${picUrl}${_GET['img']}\"" .
      "border=\"0\" alt=\"åȼʪɽޤ\"" .
      "width=\"${mesElem[0]}\" height=\"${mesElem[1]}\">");
  } else {
    print("<img src=\"$picUrl" . "Thumbnails/" .  $_GET['img'] . "_thumb.jpg\"
      border=\"0\" alt=\"åȼʪɽޤ\">");
  }

  // Ȥɽ
  echo <<<EOD
</a></td></tr></table></td></tr><tr><td colspan="2">
<hr class="right" align="center" size="1">
&nbsp;&nbsp; <a href="#ac">[Ȥ]</a></br>
EOD;

  if (count($mesText) > 1) {
    for ($i = 1; $i < count($mesText); $i++) {
      $repElem = explode("|||", $mesText[$i]);
      $repElem[0] = htmlspecialchars($repElem[0]);
      $repElem[1] = messageParse($repElem[1]);
      $repElem[2] = trim($repElem[2]);
      print("<div class=\"comname\"><strong>${repElem[0]}</strong> " .
        "[${repElem[2]}]</div>");
      print("<div class=\"comtext\">${repElem[1]}</div>");
    }
  }

  echo <<<EOD
<form action="./comment.php" method="POST">
<input type="hidden" name="repImg" value="${_GET['img']}">
<a name="ac"><hr class="right" align="center" size="1"></a>
&nbsp;&nbsp;Ȥ<br><br>
<table>
<tr><td align="right">̾</td>
<td><input type="text" name="repName" size="40" ${repValue}></td></tr>
<tr><td align="right"></td>
<td><textarea name="repCom" rows="5" cols="40"></textarea></td></tr>
<tr><td align="right">Cookie </td><td>
<input class="cb" type="checkbox" name="repCookie" checked value="true"></td></tr>
<tr><td></td>
<td><input type="submit" value="">
<input type="reset" value="ꥻå"></td></tr>
</table>
</form>
</td></tr>
EOD;

} elseif (isset($_GET['new'])) {
  // ƥեɽ
  print("<h4>᡼");
  if ($adminOnly) {
    print("<span class=\"notice\"> (ԤΤƲǽ)</span>");
  }
  print("</h4>");

  echo <<<EOD
<form enctype="multipart/form-data" action="./submit.php" method="POST">
<table><tr><td align="right">̾</td><td>
<input type="text" name="title" size="40"></td></tr>
<tr><td align="right">̾</td><td>
<input type="text" name="name" size="40" ${nameValue}>
<span class="notice"> (ɬ)</span></td></tr>
<tr><td align="right">᡼륢ɥ쥹</td><td>
<input type="text" name="email" size="40" ${mailValue}></td></tr>
<tr><td align="right">ե</td><td>
<input type="file" name="fileName" size="40">
<span class="notice"> (ɬ)</span></td></tr>
<tr><td align="right"></td><td>
<textarea name="comment" rows="10" cols="40"></textarea></td></tr>
<tr><td align="right">ѥ</td><td>
<input type="password" name="userPass" size="10" ${passValue}>
<span class="notice"> (ɬܡȾѱѿΤ)</span></td></tr>
<tr><td align="right">ư̾</td><td>
<input class="cb" type="checkbox" name="newAuto" value="true">
<span class="notice"> (JPEG ᡼Τߤͭ)</span></td></tr>
<tr><td align="right">Cookie </td><td>
<input class="cb" type="checkbox" name="useCookie" checked value="true"></td></tr>
<tr><td></td><td>
<input type="submit" value="">
<input type="reset" value="ꥻå"></td></tr></table>
</form>
EOD;

} else {
  // ɽɽ
  print("<tr><td align=\"center\"><br><br><br><br><br>");
  if ($bannerImg != "") {
    print("<img src=\"${bannerImg}\">");
  }
  print("<h4>${albumTitle}</h4>");
  print("<span class=\"notice\">Х: ");
  if ($adminMail != "") {
    print("<a href=\"mailto:${adminMail}\">${adminName}</a>");
  } else {
    print("${adminName}");
  }
  print("<br>᡼ƥ⡼: ");
  if ($adminOnly) {
    print("ԤΤ");
  } else {
    print("̵");
  }
  print("</span><br><br><br><br><br></td></tr>");
}
?>


</td></tr></table>


<?php
if (isset($_GET['img'])) {

  echo <<<EOD
<tr><td class="button" align="right">
<form action="./delete.php" method="POST" style="margin:0px;">
<input type="hidden" name="delImg" value="${_GET['img']}">
ѥ
<input type="password" name="delPasswd" size="10">
<input type="submit" name="delButton" value="">
<input type="submit" name="editButton" value="">
</form>
</td></tr>
EOD;

}
?>


</td></tr></table>
</body>
</html>

==> bbwa-0.0.6.tar.gz: bbwa-0.0.6/right.php <==
<?php
//
// BBWA
// right.php
// Ʋɽ
// Teppei KAKU <teppei@sat.co.jp>
//

include("variables.php");
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">


<?php
print("<link rel=\"stylesheet\" type=\"text/css\" href=\"Themes/${theme}.css\">");
?>


<script language="JavaScript">
<!--
function openWindow(urlString) {
  var arg = "toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes";
  LARGEVIEW = window.open(urlString, "LRGEVIEW", arg);
  LARGEVIEW.focus();
}
//-->
</script>
<noscript>
<h4><blink>
顼: JavaScript ͭˤʤȤޤ!!
</blink></h4>
</noscript>
</head>
<body class="right">
<table border="0" width="100%" align="center">


<?php
include("functions.php");

// åɤ߹
if (isset($_COOKIE['NAME'])) {
  $nameValue = "value=\"" . htmlspecialchars($_COOKIE['NAME']) . "\"";
} else {
  $nameValue = "";
}
if (isset($_COOKIE['EMAIL'])) {
  $mailValue = "value=\"" . htmlspecialchars($_COOKIE['EMAIL']) . "\"";
} else {
  $mailValue = "";
}
if (isset($_COOKIE['PASS'])) {
  $passValue = "value=\"" . htmlspecialchars($_COOKIE['PASS']) . "\"";
} else {
  $passValue = "";
}
if (isset($_COOKIE['REPNAME'])) {
  $repValue = "value=\"" . htmlspecialchars($_COOKIE['REPNAME']) . "\"";
} else {
  $repValue = "";
}
?>


<tr><td class="right">
<table border="0" width="100%">


<?php
if (isset($_GET['img'])) {
  // ξܺپɽ

  // ʤɤɤ߹
  $imgSize = getimagesize($dirName . $_GET['img']);
  $mesText = file("${dirName}Messages/${_GET['img']}_mes.txt");
  $mesElem = explode("|||", $mesText[0]);

  // ɤ߹
  $iList = file("${dirName}INDEX");
  foreach ($iList as $iText) {
    if (strstr($iText, $_GET['img'])) {
      $iArray = explode("|||", trim($iText));
      break;
    }
  }
  if ($iArray[2] == 0) {
    $score = 0;
  } else {
    $score = round($iArray[2] * 100 / $iArray[3]);
  }

  print("<tr><td valign=\"top\">");
  print("<table border=\"0\">");

  print("<tr><td nowrap align=\"right\" valign=\"top\">ȥ:</td><td>");
  print("<a href=\"JavaScript:openWindow('./largeview.php?img=${_GET['img']}')\">");
  $mesElem[2] = htmlspecialchars($mesElem[2]);
  print("<strong>${mesElem[2]}</strong></a></td></tr>");

  print("<tr><td nowrap align=\"right\" valign=\"top\">Ƽ:</td><td>");
  if ($mesElem[4] != "NOMAIL") {
    $mesElem[4] = htmlspecialchars($mesElem[4]);
    print("<a href=\"mailto:${mesElem[4]}\">");
  }
  $mesElem[3] = htmlspecialchars($mesElem[3]);
  print("<strong>${mesElem[3]}</strong>");
  if ($mesElem[4] != "NOMAIL") {
    print("</a>");
  }
  print("</td></tr>");

  print("<tr><td nowrap align=\"right\" valign=\"top\">:</td><td>");
  print("<strong>${mesElem[5]}</strong></td></tr>");

  $fSize = (int) ((filesize($dirName . $_GET['img']) / 1024) + 1);
  print("<tr><td nowrap align=\"right\" valign=\"top\">:</td>");
  print("<td>${imgSize[0]}x${imgSize[1]} ԥ, ${fSize} KB</td></tr>");

  print("<tr><td nowrap align=\"right\" valign=\"top\">:</td>");
  print("<td class=\"score\" valign=\"middle\">" .
    "<img src=\"score.php?score=${score}\" width=\"100\" height=\"8\">" .
    " ${score}%</td></tr>");
  print("<tr><td class=\"score\"></td>");
  print("<td class=\"score\" valign=\"middle\">ɼ" .
    " <a href=\"score.php?img=${_GET['img']}&vote=g\">[Good]</a>" .
    " <a href=\"score.php?img=${_GET['img']}&vote=b\">[Bad]</a>" .
    "</td></tr>");

  print("<tr><td nowrap align=\"right\" valign=\"top\"><br>:");
  if (!ereg("^NOCOM(\r\n|\r|\n)$", $mesElem[7])) {
    $mesElem[7] = messageParse($mesElem[7]);
    print("</td><td style=\"padding-right:10px;\"><br>${mesElem[7]}");
  }

  echo <<<EOD
</td></tr></table>
</td><td valign="top" align="right">
<table border="0"><tr><td class="photoframe" align="center">
<a href="JavaScript:openWindow('./largeview.php?img=${_GET['img']}')">
EOD;

  if (eregi("\.gif$", $_GET['img'])) {
    print("<img src=\"${picUrl}${_GET['img']}\"" .
      "border=\"0\" alt=\"åȼʪɽޤ\"" .
      "width=\"${mesElem[0]}\" height=\"${mesElem[1]}\">");
  } else {
    print("<img src=\"$picUrl" . "Thumbnails/" .  $_GET['img'] . "_thumb.jpg\"
      border=\"0\" alt=\"åȼʪɽޤ\">");
  }

  // Ȥɽ
  echo <<<EOD
</a></td></tr></table></td></tr><tr><td colspan="2">
<hr class="right" align="center" size="1">
&nbsp;&nbsp; <a href="#ac">[Ȥ]</a></br>
EOD;

  if (count($mesText) > 1) {
    for ($i = 1; $i < count($mesText); $i++) {
      $repElem = explode("|||", $mesText[$i]);
      $repElem[0] = htmlspecialchars($repElem[0]);
      $repElem[1] = messageParse($repElem[1]);
      $repElem[2] = trim($repElem[2]);
      print("<div class=\"comname\"><strong>${repElem[0]}</strong> " .
        "[${repElem[2]}]</div>");
      print("<div class=\"comtext\">${repElem[1]}</div>");
    }
  }

  echo <<<EOD
<form action="./comment.php" method="POST">
<input type="hidden" name="repImg" value="${_GET['img']}">
<a name="ac"><hr class="right" align="center" size="1"></a>
&nbsp;&nbsp;Ȥ<br><br>
<table>
<tr><td align="right">̾</td>
<td><input type="text" name="repName" size="40" ${repValue}></td></tr>
<tr><td align="right"></td>
<td><textarea name="repCom" rows="5" cols="40"></textarea></td></tr>
<tr><td align="right">Cookie </td><td>
<input class="cb" type="checkbox" name="repCookie" checked value="true"></td></tr>
<tr><td></td>
<td><input type="submit" value="">
<input type="reset" value="ꥻå"></td></tr>
</table>
</form>
</td></tr>
EOD;

} elseif (isset($_GET['new'])) {
  // ƥեɽ
  print("<h4>᡼");
  if ($adminOnly) {
    print("<span class=\"notice\"> (ԤΤƲǽ)</span>");
  }
  print("</h4>");

  echo <<<EOD
<form enctype="multipart/form-data" action="./submit.php" method="POST">
<table><tr><td align="right">̾</td><td>
<input type="text" name="title" size="40"></td></tr>
<tr><td align="right">̾</td><td>
<input type="text" name="name" size="40" ${nameValue}>
<span class="notice"> (ɬ)</span></td></tr>
<tr><td align="right">᡼륢ɥ쥹</td><td>
<input type="text" name="email" size="40" ${mailValue}></td></tr>
<tr><td align="right">ե</td><td>
<input type="file" name="fileName" size="40">
<span class="notice"> (ɬ)</span></td></tr>
<tr><td align="right"></td><td>
<textarea name="comment" rows="10" cols="40"></textarea></td></tr>
<tr><td align="right">ѥ</td><td>
<input type="password" name="userPass" size="10" ${passValue}>
<span class="notice"> (ɬܡȾѱѿΤ)</span></td></tr>
<tr><td align="right">ư̾</td><td>
<input class="cb" type="checkbox" name="newAuto" value="true">
<span class="notice"> (JPEG ᡼Τߤͭ)</span></td></tr>
<tr><td align="right">Cookie </td><td>
<input class="cb" type="checkbox" name="useCookie" checked value="true"></td></tr>
<tr><td></td><td>
<input type="submit" value="">
<input type="reset" value="ꥻå"></td></tr></table>
</form>
EOD;

} else {
  // ɽɽ
  print("<tr><td align=\"center\"><br><br><br><br><br>");
  if ($bannerImg != "") {
    print("<img src=\"${bannerImg}\">");
  }
  print("<h4>${albumTitle}</h4>");
  print("<span class=\"notice\">Х: ");
  if ($adminMail != "") {
    print("<a href=\"mailto:${adminMail}\">${adminName}</a>");
  } else {
    print("${adminName}");
  }
  print("<br>᡼ƥ⡼: ");
  if ($adminOnly) {
    print("ԤΤ");
  } else {
    print("̵");
  }
  print("<br>ե륵: ${maxFileSize} KB");
  print("</span><br><br><br><br><br></td></tr>");
}
?>


</td></tr></table>


<?php
if (isset($_GET['img'])) {

  echo <<<EOD
<tr><td class="button" align="right">
<form action="./delete.php" method="POST" style="margin:0px;">
<input type="hidden" name="delImg" value="${_GET['img']}">
ѥ
<input type="password" name="delPasswd" size="10">
<input type="submit" name="delButton" value="">
<input type="submit" name="editButton" value="">
</form>
</td></tr>
EOD;

}
?>


</td></tr></table>
</body>
</html>
